@@ -1,25 +1,45 @@
 package Git::Repository::Status;
-{
-  $Git::Repository::Status::VERSION = '0.02';
-}
-#ABSTRACT: Class representing git status data
 
 use strict;
 use warnings;
 use 5.006;
 
+our $VERSION = '0.03';
+
 sub index { return $_[0]->[0] }
 sub work  { return $_[0]->[1] }
 sub status { $_[0]->[0] . $_[0]->[1] }
 sub path1 { return $_[0]->[2] }
 sub path2 { return $_[0]->[3] }
 
-sub ignored { return $_[0]->[0] eq '?' }
-sub tracked { return $_[0]->[0] ne '!' }
+sub ignored { return $_[0]->[0] eq '!' }
+sub tracked { return $_[0]->[0] ne '?' }
+
+our %INDEX_COLORS = (
+    A   => 'green',
+    M   => 'green',
+    D   => 'green',
+    R   => 'green',
+    C   => 'green', # sure?    
+    U   => 'red',   # sure?
+    ' ' => 'green',
+    '?' => 'red',
+    '!' => 'red',
+);
+
+our %WORK_COLORS = (
+    M   => 'red',
+    D   => 'red',
+    U   => 'red', # sure?
+    ' ' => 'green',
+    '?' => 'red',
+    '!' => 'red',
+);
+
+sub index_color { $INDEX_COLORS{$_[0]->[0]} }
+sub work_color { $WORK_COLORS{$_[0]->[1]} }
 
 our %MEANINGS = (
-          ' M'  => 'not updated',
-          ' D'  => 'not updated',
           'MM'  => 'updated in index',
           'MD'  => 'updated in index',
           'AM'  => 'added to index',
@@ -32,20 +52,20 @@ our %MEANINGS = (
           'C '  => 'copied in index',
           'CM'  => 'copied in index',
           'CD'  => 'copied in index',
-          'M '  => 'index and work tree matches',
-          'A '  => 'index and work tree matches',
-          'R '  => 'index and work tree matches',
-          'C '  => 'index and work tree matches',
-          ' M'   => 'work tree changed since index',
-          'MM'   => 'work tree changed since index',
-          'AM'   => 'work tree changed since index',
-          'RM'   => 'work tree changed since index',
-          'CM'   => 'work tree changed since index',
-          ' D'   => 'deleted in work tree',
-          'MD'   => 'deleted in work tree',
-          'AD'   => 'deleted in work tree',
-          'RD'   => 'deleted in work tree',
-          'CD'   => 'deleted in work tree',
+          'M '  => 'modified in index and work tree',
+          'A '  => 'added in index and work tree',
+          'R '  => 'renamed in index and work tree',
+          'C '  => 'copied in index and work tree',
+          ' M'  => 'work tree changed since index',
+          'MM'  => 'work tree changed since index',
+          'AM'  => 'work tree changed since index',
+          'RM'  => 'work tree changed since index',
+          'CM'  => 'work tree changed since index',
+          ' D'  => 'deleted in work tree',
+          'MD'  => 'deleted in work tree',
+          'AD'  => 'deleted in work tree',
+          'RD'  => 'deleted in work tree',
+          'CD'  => 'deleted in work tree',
           'DD'  => 'unmerged, both deleted',
           'AU'  => 'unmerged, added by us',
           'UD'  => 'unmerged, deleted by them',
@@ -57,10 +77,12 @@ our %MEANINGS = (
           '!!'  => 'ignored'
 );
 
-sub meaning { return $MEANINGS{$_[0]->status} }
+sub meaning { 
+    return $MEANINGS{$_[0]->status} 
+}
 
 sub unmerged {
-	return $_[0]->status =~ /^(D[DU]|A[UA]|U[DAU])$/
+    return $_[0]->status =~ /^(D[DU]|A[UA]|U[DAU])$/
 }
 
 sub new {
@@ -70,30 +92,26 @@ sub new {
 
 1;
 
-__END__
-
-=pod
-
 =head1 NAME
 
-Git::Repository::Status - Class representing git status data
-
-=head1 VERSION
-
-version 0.02
+Git::Repository::Status - git repository status information as Perl module
 
 =head1 SYNOPSIS
 
     # load the Status plugin
-	use Git::Repository 'Status';
- 
-	# get the status of all files
-	my @status = Git::Repository->status('--ignored');
- 
-	# print all ignored files
-	for (@status) {
-	    say $_->path1 if $_->ignored;
-	}
+    use Git::Repository 'Status';
+
+    # get the status of all files
+    my @status = Git::Repository->new->status('--ignored');
+
+    # print all files with status with color
+    use Term::ANSIColor;
+    for (@status) {
+        say colored($_->index,$_->index_color) 
+          . colored($_->work, $_->work_color) 
+          . " " . $_->path1 . "\t" 
+          . colored($_->meaning,'yellow');
+    }
 
 =head1 DESCRIPTION
 
@@ -144,6 +162,14 @@ Returns true if the path is being tracked.
 
 Returns the human readable status meaning as listed in the git manual.
 
+=item work_color
+
+Returns a color (either C<red> or C<green>) for display of work status.
+
+=item work_color
+
+Returns a color (either C<red> or C<green>) for display of index status.
+
 =back
 
 =head1 SEE ALSO
@@ -158,9 +184,9 @@ Jakob Voß
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Jakob Voß.
+This software is copyright (c) 2014 by Jakob Voß.
 
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under the same
+terms as the Perl 5 programming language system itself.
 
 =cut
